@@ -6,7 +6,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2019  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2020  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -25,11 +25,27 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 #include "cmd.hpp" // IWYU pragma: export
 
+#include <osmium/io/reader.hpp>
+#include <osmium/io/writer.hpp>
+#include <osmium/util/progress_bar.hpp>
+
 #include <string>
 #include <vector>
 
 class CommandCat : public Command, public with_multiple_osm_inputs, public with_osm_output {
 
+    enum clean_options : uint8_t {
+        clean_version   = 0x01,
+        clean_changeset = 0x02,
+        clean_timestamp = 0x04,
+        clean_uid       = 0x08,
+        clean_user      = 0x10
+    };
+
+    uint8_t m_clean_attrs = 0;
+
+    void copy(osmium::ProgressBar& progress_bar, osmium::io::Reader& reader, osmium::io::Writer &writer);
+
 public:
 
     explicit CommandCat(const CommandFactory& command_factory) :
