@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2019  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2020  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -254,7 +254,6 @@ void CommandExport::canonicalize_output_format() {
 }
 
 bool CommandExport::setup(const std::vector<std::string>& arguments) {
-    const auto& map_factory = osmium::index::MapFactory<osmium::unsigned_object_id_type, osmium::Location>::instance();
     std::string default_index_type{"flex_mem"};
 
     po::options_description opts_cmd{"COMMAND OPTIONS"};
@@ -321,6 +320,7 @@ bool CommandExport::setup(const std::vector<std::string>& arguments) {
     }
 
     if (vm.count("show-index-types")) {
+        const auto& map_factory = osmium::index::MapFactory<osmium::unsigned_object_id_type, osmium::Location>::instance();
         for (const auto& map_type : map_factory.map_types()) {
             std::cout << map_type << '\n';
         }
@@ -413,10 +413,7 @@ bool CommandExport::setup(const std::vector<std::string>& arguments) {
     }
 
     if (vm.count("index-type")) {
-        m_index_type_name = vm["index-type"].as<std::string>();
-        if (m_index_type_name != "none" && !map_factory.has_map_type(m_index_type_name)) {
-            throw argument_error{std::string{"Unknown index type '"} + m_index_type_name + "'. Use --show-index-types or -I to get a list."};
-        }
+        m_index_type_name = check_index_type(vm["index-type"].as<std::string>());
     }
 
     if (vm.count("keep-untagged")) {
