@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2019  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2020  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -165,9 +165,12 @@ osmium::StringMatcher get_string_matcher(std::string string) {
     return osmium::StringMatcher::substring{s};
 }
 
-osmium::TagMatcher get_tag_matcher(const std::string& expression) {
+osmium::TagMatcher get_tag_matcher(const std::string& expression, bool *has_value_matcher) {
     const auto op_pos = expression.find('=');
     if (op_pos == std::string::npos) {
+        if (has_value_matcher) {
+            *has_value_matcher = false;
+        }
         return osmium::TagMatcher{get_string_matcher(expression)};
     }
 
@@ -180,6 +183,9 @@ osmium::TagMatcher get_tag_matcher(const std::string& expression) {
         invert = true;
     }
 
+    if (has_value_matcher) {
+        *has_value_matcher = true;
+    }
     return osmium::TagMatcher{get_string_matcher(key), get_string_matcher(value), invert};
 }
 
