@@ -6,7 +6,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2019  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2020  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ osmium::osm_entity_bits::type get_types(const std::string& str);
 std::pair<osmium::osm_entity_bits::type, std::string> get_filter_expression(const std::string& str);
 void strip_whitespace(std::string& string);
 osmium::StringMatcher get_string_matcher(std::string string);
-osmium::TagMatcher get_tag_matcher(const std::string& expression);
+osmium::TagMatcher get_tag_matcher(const std::string& expression, bool *has_value_matcher = nullptr);
 void initialize_tags_filter(osmium::TagsFilter& tags_filter, bool default_result, const std::vector<std::string>& strings);
 osmium::Box parse_bbox(const std::string& str, const std::string& option_name);
 osmium::item_type parse_item_type(const std::string& t);
